@@ -24,7 +24,8 @@ from .constants import (
     POST,
     PUT,
     TRACE,
-    URL_ERROR_MESSAGE
+    URL_ERROR_MESSAGE,
+    WILDCARD
 )
 
 from .errors import AbortException, SubdomainError, UrlDuplicateError, UrlError
@@ -336,7 +337,7 @@ class Router(object):
         metadata = preprocessor(scope)
         subdomain = metadata[0]
         wildcard_engine = self.subdomains.get(WILDCARD)
-        engine = self.subdomains.get(subdomain):
+        engine = self.subdomains.get(subdomain)
         if not engine:
             engine = wildcard_engine if wildcard_engine else self.subdomains.get(DEFAULT)
 
